@@ -139,6 +139,8 @@ func chineseTranslationSet() TranslationSet {
 		SureApplyStashEntry:                 "您确定要应用此贮藏条目？",
 		NoTrackedStagedFilesStash:           "没有可以贮藏的已跟踪/暂存文件",
 		StashChanges:                        "贮藏更改",
+		LcRenameStash:                       "rename stash",
+		RenameStashPrompt:                   "Rename stash: {{.stashName}}",
 		OpenConfig:                          "打开配置文件",
 		EditConfig:                          "编辑配置文件",
 		ForcePush:                           "强制推送",
@@ -176,7 +178,7 @@ func chineseTranslationSet() TranslationSet {
 		ToggleDragSelect:                    `切换拖动选择`,
 		ToggleSelectHunk:                    `切换选择区块`,
 		ToggleSelectionForPatch:             `添加/移除 行到补丁`,
-		TogglePanel:                         `切换到其他面板`,
+		ToggleStagingPanel:                  `切换到其他面板`,
 		ReturnToFilesPanel:                  `返回文件面板`,
 		FastForward:                         `从上游快进此分支`,
 		Fetching:                            "抓取并快进 {{.from}} -> {{.to}} ...",
@@ -298,7 +300,7 @@ func chineseTranslationSet() TranslationSet {
 		PatchOptionsTitle:                   "补丁选项",
 		NoPatchError:                        "尚未创建补丁。你可以在提交中的文件上按下“空格”或使用“回车”添加其中的特定行以开始构建补丁",
 		LcEnterFile:                         "输入文件以将所选行添加到补丁中（或切换目录折叠）",
-		ExitLineByLineMode:                  `退出逐行模式`,
+		ExitCustomPatchBuilder:              `退出逐行模式`,
 		EnterUpstream:                       `以这种格式输入上游：'<远程仓库> <分支名称>'`,
 		InvalidUpstream:                     "上游格式无效，格式应当为：'<remote> <branchname>'",
 		ReturnToRemotesList:                 `返回远程仓库列表`,
@@ -507,7 +509,7 @@ func chineseTranslationSet() TranslationSet {
 			UnstageFile:                       "取消暂存文件",
 			UnstageAllFiles:                   "取消暂存所有文件",
 			StageAllFiles:                     "暂存所有文件",
-			IgnoreExcludeFile:                 "忽略文件",
+			LcIgnoreExcludeFile:               "忽略文件",
 			Commit:                            "提交 (Commit)",
 			EditFile:                          "编辑文件",
 			Push:                              "推送 (Push)",
@@ -530,6 +532,7 @@ func chineseTranslationSet() TranslationSet {
 			UpdateRemote:                      "更新远程",
 			ApplyPatch:                        "应用补丁",
 			Stash:                             "贮藏 (Stash)",
+			RenameStash:                       "Rename stash",
 			RemoveSubmodule:                   "删除子模块",
 			ResetSubmodule:                    "重置子模块",
 			AddSubmodule:                      "添加子模块",
