@@ -105,6 +105,8 @@ func dutchTranslationSet() TranslationSet {
 		SureApplyStashEntry:                 "Weet je zeker dat je deze stash entry wil toepassen?",
 		NoTrackedStagedFilesStash:           "Je hebt geen tracked/staged bestanden om te laten stashen",
 		StashChanges:                        "Stash veranderingen",
+		LcRenameStash:                       "rename stash",
+		RenameStashPrompt:                   "Rename stash: {{.stashName}}",
 		NoChangedFiles:                      "Geen veranderde bestanden",
 		OpenConfig:                          "open config bestand",
 		EditConfig:                          "verander config bestand",
@@ -141,7 +143,7 @@ func dutchTranslationSet() TranslationSet {
 		ToggleDragSelect:                    `toggle drag selecteer`,
 		ToggleSelectHunk:                    `toggle selecteer hunk`,
 		ToggleSelectionForPatch:             `voeg toe/verwijder lijn(en) in patch`,
-		TogglePanel:                         `ga naar een ander paneel`,
+		ToggleStagingPanel:                  `ga naar een ander paneel`,
 		ReturnToFilesPanel:                  `ga terug naar het bestanden paneel`,
 		FastForward:                         `fast-forward deze branch vanaf zijn upstream`,
 		Fetching:                            "fetching en fast-forwarding {{.from}} -> {{.to}} ...",
@@ -258,7 +260,7 @@ func dutchTranslationSet() TranslationSet {
 		PatchOptionsTitle:                   "Patch Opties",
 		NoPatchError:                        "Nog geen patch gecreëerd. Om een patch te bouwen gebruik 'space' op een commit bestand of 'enter' om een spesiefieke lijnen toe te voegen",
 		LcEnterFile:                         "enter bestand om geselecteerde regels toe te voegen aan de patch",
-		ExitLineByLineMode:                  `sluit lijn-bij-lijn modus`,
+		ExitCustomPatchBuilder:              `sluit lijn-bij-lijn modus`,
 		EnterUpstream:                       `Enter upstream als '<remote> <branchnaam>'`,
 		ReturnToRemotesList:                 `ga terug naar remotes lijst`,
 		LcAddNewRemote:                      `voeg een nieuwe remote toe`,
