@@ -130,6 +130,8 @@ func japaneseTranslationSet() TranslationSet {
 		SureApplyStashEntry: "Stashを適用します。よろしいですか?",
 		// NoTrackedStagedFilesStash:           "You have no tracked/staged files to stash",
 		StashChanges:      "変更をStash",
+		LcRenameStash:     "Stashを変更",
+		RenameStashPrompt: "Stash名を変更: {{.stashName}}",
 		OpenConfig:        "設定ファイルを開く",
 		EditConfig:        "設定ファイルを編集",
 		ForcePush:         "Force push",
@@ -176,7 +178,7 @@ func japaneseTranslationSet() TranslationSet {
 		ToggleDragSelect:        `範囲選択を切り替え`,
 		ToggleSelectHunk:        `hunk選択を切り替え`,
 		ToggleSelectionForPatch: `行をパッチに追加/削除`,
-		TogglePanel:             `パネルを切り替え`,
+		ToggleStagingPanel:      `パネルを切り替え`,
 		ReturnToFilesPanel:      `ファイル一覧に戻る`,
 		// FastForward:                         `fast-forward this branch from its upstream`,
 		// Fetching:                            "fetching and fast-forwarding {{.from}} -> {{.to}} ...",
@@ -303,7 +305,7 @@ func japaneseTranslationSet() TranslationSet {
 		// PatchOptionsTitle:                   "Patch Options",
 		// NoPatchError:                        "No patch created yet. To start building a patch, use 'space' on a commit file or enter to add specific lines",
 		// LcEnterFile:                         "enter file to add selected lines to the patch (or toggle directory collapsed)",
-		ExitLineByLineMode:        `line-by-lineモードを終了`,
+		// ExitCustomPatchBuilder:    ``,
 		EnterUpstream:             `'<remote> <branchname>' の形式でupstreamを入力`,
 		InvalidUpstream:           "upstreamの形式が正しくありません。'<remote> <branchname>' の形式で入力してください。",
 		ReturnToRemotesList:       `リモート一覧に戻る`,
@@ -533,7 +535,7 @@ func japaneseTranslationSet() TranslationSet {
 			UnstageFile:                       "ファイルをアンステージ",
 			UnstageAllFiles:                   "すべてのファイルをアンステージ",
 			StageAllFiles:                     "すべてのファイルをステージ",
-			IgnoreExcludeFile:                 "ファイルをignore",
+			LcIgnoreExcludeFile:               "ファイルをignore",
 			Commit:                            "コミット",
 			EditFile:                          "ファイルを編集",
 			Push:                              "Push",
@@ -556,6 +558,7 @@ func japaneseTranslationSet() TranslationSet {
 			UpdateRemote:                      "リモートを更新",
 			ApplyPatch:                        "パッチを適用",
 			Stash:                             "Stash",
+			RenameStash:                       "Stash名を変更",
 			RemoveSubmodule:                   "サブモジュールを削除",
 			ResetSubmodule:                    "サブモジュールをリセット",
 			AddSubmodule:                      "サブモジュールを追加",
