@@ -9,7 +9,7 @@ lazygit!를 이용해주셔서 감사합니다. Seriously you rock. Three things
  2) 다음 사이트에서 최신 릴리스 노트를 읽어보세요.:
       https://github.com/jesseduffield/lazygit/releases
 
- 3) 만약 당신이 Git을 사용한다면, 그것은 당신을 프로그래머로 만들 것입니다! 
+ 3) 만약 당신이 Git을 사용한다면, 그것은 당신을 프로그래머로 만들 것입니다!
 	 당신의 도움으로 우리는 lazygit을 더 좋게 만들 수 있습니다, 그러니 기여자가 되는 것을 고려해보세요. 그리고 재미에 참여하세요:
       https://github.com/jesseduffield/lazygit
     또한 오른쪽 하단의 기부 버튼을 클릭하여 저를 후원하고 작업할 내용을 알려주실 수 있습니다.
@@ -131,6 +131,8 @@ func koreanTranslationSet() TranslationSet {
 		SureApplyStashEntry:                 "정말로 Stash를 적용하시겠습니까?",
 		NoTrackedStagedFilesStash:           "You have no tracked/staged files to stash",
 		StashChanges:                        "변경을 Stash",
+		LcRenameStash:                       "rename stash",
+		RenameStashPrompt:                   "Rename stash: {{.stashName}}",
 		OpenConfig:                          "설정 파일 열기",
 		EditConfig:                          "설정 파일 수정",
 		ForcePush:                           "강제 푸시",
@@ -177,7 +179,7 @@ func koreanTranslationSet() TranslationSet {
 		ToggleDragSelect:                    `드래그 선택 전환`,
 		ToggleSelectHunk:                    `toggle select hunk`,
 		ToggleSelectionForPatch:             `line(s)을 패치에 추가/삭제`,
-		TogglePanel:                         `패널 전환`,
+		ToggleStagingPanel:                  `패널 전환`,
 		ReturnToFilesPanel:                  `파일 목록으로 돌아가기`,
 		FastForward:                         `fast-forward this branch from its upstream`,
 		Fetching:                            "fetching and fast-forwarding {{.from}} -> {{.to}} ...",
@@ -304,84 +306,84 @@ func koreanTranslationSet() TranslationSet {
 		PatchOptionsTitle:                   "Patch 옵션",
 		NoPatchError:                        "No patch created yet. To start building a patch, use 'space' on a commit file or enter to add specific lines",
 		LcEnterFile:                         "enter file to add selected lines to the patch (or toggle directory collapsed)",
-		ExitLineByLineMode:                  `line-by-line 모드 종료`,
-		EnterUpstream:                       `'<remote> <branchname>'와 같은 형식으로 입력하세요.`,
-		InvalidUpstream:                     "upstream의 형식이 잘못되었습니다.'<remote> <branchname>' 와 같은 형식으로 입력하세요.",
-		ReturnToRemotesList:                 `원격목록으로 돌아가기`,
-		LcAddNewRemote:                      `새로운 Remote 추가`,
-		LcNewRemoteName:                     `새로운 Remote 이름:`,
-		LcNewRemoteUrl:                      `새로운 Remote URL:`,
-		LcEditRemoteName:                    `{{.remoteName}} 의 새로운 Remote 이름 입력:`,
-		LcEditRemoteUrl:                     `{{.remoteName}} 의 새로운 Remote URL 입력:`,
-		LcRemoveRemote:                      `Remote를 삭제`,
-		LcRemoveRemotePrompt:                "정말로 Remote를 삭제하시겠습니까?",
-		DeleteRemoteBranch:                  "원격 브랜치를 삭제",
-		DeleteRemoteBranchMessage:           "정말로 원격 브랜치를 삭제하시겠습니까?",
-		LcSetUpstream:                       "set as upstream of checked-out branch",
-		SetUpstreamTitle:                    "Set upstream branch",
-		SetUpstreamMessage:                  "Are you sure you want to set the upstream branch of '{{.checkedOut}}' to '{{.selected}}'",
-		LcEditRemote:                        "Remote를 수정",
-		LcTagCommit:                         "tag commit",
-		TagMenuTitle:                        "태그 작성",
-		TagNameTitle:                        "태그 이름:",
-		TagMessageTitle:                     "태그 메시지: ",
-		LcAnnotatedTag:                      "annotated tag",
-		LcLightweightTag:                    "lightweight tag",
-		LcDeleteTag:                         "태그 삭제",
-		DeleteTagTitle:                      "태그 삭제",
-		DeleteTagPrompt:                     "정말로 태그 '{{.tagName}}' 를 삭제하시겠습니까?",
-		PushTagTitle:                        "원격에 태그 '{{.tagName}}' 를 푸시",
-		LcPushTag:                           "태그를 push",
-		LcCreateTag:                         "태그를 생성",
-		CreateTagTitle:                      "태그 이름:",
-		LcFetchRemote:                       "원격을 업데이트",
-		FetchingRemoteStatus:                "원격을 업데이트 중",
-		LcCheckoutCommit:                    "커밋을 체크아웃",
-		SureCheckoutThisCommit:              "정말로 선택한 커밋을 체크아웃 하시겠습니까?",
-		LcGitFlowOptions:                    "git-flow 옵션 보기",
-		NotAGitFlowBranch:                   "This does not seem to be a git flow branch",
-		NewGitFlowBranchPrompt:              "new {{.branchType}} name:",
-		IgnoreTracked:                       "Ignore tracked file",
-		IgnoreTrackedPrompt:                 "Are you sure you want to ignore a tracked file?",
-		LcViewResetToUpstreamOptions:        "view upstream reset options",
-		LcNextScreenMode:                    "다음 스크린 모드 (normal/half/fullscreen)",
-		LcPrevScreenMode:                    "이전 스크린 모드",
-		LcStartSearch:                       "검색 시작",
-		Panel:                               "패널",
-		Keybindings:                         "키 바인딩",
-		LcRenameBranch:                      "브랜치 이름 변경",
-		NewBranchNamePrompt:                 "새로운 브랜치 이름 입력",
-		RenameBranchWarning:                 "This branch is tracking a remote. This action will only rename the local branch name, not the name of the remote branch. Continue?",
-		LcOpenMenu:                          "매뉴 열기",
-		LcResetCherryPick:                   "reset cherry-picked (copied) commits selection",
-		LcNextTab:                           "이전 탭",
-		LcPrevTab:                           "다음 탭",
-		LcCantUndoWhileRebasing:             "리베이스중에는 되돌릴 수 없습니다.",
-		LcCantRedoWhileRebasing:             "리베이스중에는 다시 실행할 수 없습니다.",
-		MustStashWarning:                    "Pulling a patch out into the index requires stashing and unstashing your changes. If something goes wrong, you'll be able to access your files from the stash. Continue?",
-		MustStashTitle:                      "Must stash",
-		ConfirmationTitle:                   "확인 패널",
-		LcPrevPage:                          "이전 페이지",
-		LcNextPage:                          "다음 페이지",
-		LcGotoTop:                           "맨 위로 스크롤 ",
-		LcGotoBottom:                        "맨 아래로 스크롤 ",
-		LcFilteringBy:                       "filtering by",
-		ResetInParentheses:                  "(reset)",
-		LcOpenFilteringMenu:                 "view filter-by-path options",
-		LcFilterBy:                          "filter by",
-		LcExitFilterMode:                    "stop filtering by path",
-		LcFilterPathOption:                  "enter path to filter by",
-		EnterFileName:                       "Enter path:",
-		FilteringMenuTitle:                  "Filtering",
-		MustExitFilterModeTitle:             "Command not available",
-		MustExitFilterModePrompt:            "Command not available in filtered mode. Exit filtered mode?",
-		LcDiff:                              "Diff",
-		LcEnterRefToDiff:                    "enter ref to diff",
-		LcEnteRefName:                       "ref 입력:",
-		LcExitDiffMode:                      "Diff 모드 종료",
-		DiffingMenuTitle:                    "Diff",
-		LcSwapDiff:                          "reverse diff direction",
-		LcOpenDiffingMenu:                   "Diff 메뉴 열기",
+		// ExitCustomPatchBuilder:              ``,
+		EnterUpstream:                `'<remote> <branchname>'와 같은 형식으로 입력하세요.`,
+		InvalidUpstream:              "upstream의 형식이 잘못되었습니다.'<remote> <branchname>' 와 같은 형식으로 입력하세요.",
+		ReturnToRemotesList:          `원격목록으로 돌아가기`,
+		LcAddNewRemote:               `새로운 Remote 추가`,
+		LcNewRemoteName:              `새로운 Remote 이름:`,
+		LcNewRemoteUrl:               `새로운 Remote URL:`,
+		LcEditRemoteName:             `{{.remoteName}} 의 새로운 Remote 이름 입력:`,
+		LcEditRemoteUrl:              `{{.remoteName}} 의 새로운 Remote URL 입력:`,
+		LcRemoveRemote:               `Remote를 삭제`,
+		LcRemoveRemotePrompt:         "정말로 Remote를 삭제하시겠습니까?",
+		DeleteRemoteBranch:           "원격 브랜치를 삭제",
+		DeleteRemoteBranchMessage:    "정말로 원격 브랜치를 삭제하시겠습니까?",
+		LcSetUpstream:                "set as upstream of checked-out branch",
+		SetUpstreamTitle:             "Set upstream branch",
+		SetUpstreamMessage:           "Are you sure you want to set the upstream branch of '{{.checkedOut}}' to '{{.selected}}'",
+		LcEditRemote:                 "Remote를 수정",
+		LcTagCommit:                  "tag commit",
+		TagMenuTitle:                 "태그 작성",
+		TagNameTitle:                 "태그 이름:",
+		TagMessageTitle:              "태그 메시지: ",
+		LcAnnotatedTag:               "annotated tag",
+		LcLightweightTag:             "lightweight tag",
+		LcDeleteTag:                  "태그 삭제",
+		DeleteTagTitle:               "태그 삭제",
+		DeleteTagPrompt:              "정말로 태그 '{{.tagName}}' 를 삭제하시겠습니까?",
+		PushTagTitle:                 "원격에 태그 '{{.tagName}}' 를 푸시",
+		LcPushTag:                    "태그를 push",
+		LcCreateTag:                  "태그를 생성",
+		CreateTagTitle:               "태그 이름:",
+		LcFetchRemote:                "원격을 업데이트",
+		FetchingRemoteStatus:         "원격을 업데이트 중",
+		LcCheckoutCommit:             "커밋을 체크아웃",
+		SureCheckoutThisCommit:       "정말로 선택한 커밋을 체크아웃 하시겠습니까?",
+		LcGitFlowOptions:             "git-flow 옵션 보기",
+		NotAGitFlowBranch:            "This does not seem to be a git flow branch",
+		NewGitFlowBranchPrompt:       "new {{.branchType}} name:",
+		IgnoreTracked:                "Ignore tracked file",
+		IgnoreTrackedPrompt:          "Are you sure you want to ignore a tracked file?",
+		LcViewResetToUpstreamOptions: "view upstream reset options",
+		LcNextScreenMode:             "다음 스크린 모드 (normal/half/fullscreen)",
+		LcPrevScreenMode:             "이전 스크린 모드",
+		LcStartSearch:                "검색 시작",
+		Panel:                        "패널",
+		Keybindings:                  "키 바인딩",
+		LcRenameBranch:               "브랜치 이름 변경",
+		NewBranchNamePrompt:          "새로운 브랜치 이름 입력",
+		RenameBranchWarning:          "This branch is tracking a remote. This action will only rename the local branch name, not the name of the remote branch. Continue?",
+		LcOpenMenu:                   "매뉴 열기",
+		LcResetCherryPick:            "reset cherry-picked (copied) commits selection",
+		LcNextTab:                    "이전 탭",
+		LcPrevTab:                    "다음 탭",
+		LcCantUndoWhileRebasing:      "리베이스중에는 되돌릴 수 없습니다.",
+		LcCantRedoWhileRebasing:      "리베이스중에는 다시 실행할 수 없습니다.",
+		MustStashWarning:             "Pulling a patch out into the index requires stashing and unstashing your changes. If something goes wrong, you'll be able to access your files from the stash. Continue?",
+		MustStashTitle:               "Must stash",
+		ConfirmationTitle:            "확인 패널",
+		LcPrevPage:                   "이전 페이지",
+		LcNextPage:                   "다음 페이지",
+		LcGotoTop:                    "맨 위로 스크롤 ",
+		LcGotoBottom:                 "맨 아래로 스크롤 ",
+		LcFilteringBy:                "filtering by",
+		ResetInParentheses:           "(reset)",
+		LcOpenFilteringMenu:          "view filter-by-path options",
+		LcFilterBy:                   "filter by",
+		LcExitFilterMode:             "stop filtering by path",
+		LcFilterPathOption:           "enter path to filter by",
+		EnterFileName:                "Enter path:",
+		FilteringMenuTitle:           "Filtering",
+		MustExitFilterModeTitle:      "Command not available",
+		MustExitFilterModePrompt:     "Command not available in filtered mode. Exit filtered mode?",
+		LcDiff:                       "Diff",
+		LcEnterRefToDiff:             "enter ref to diff",
+		LcEnteRefName:                "ref 입력:",
+		LcExitDiffMode:               "Diff 모드 종료",
+		DiffingMenuTitle:             "Diff",
+		LcSwapDiff:                   "reverse diff direction",
+		LcOpenDiffingMenu:            "Diff 메뉴 열기",
 		// the actual view is the extras view which I intend to give more tabs in future but for now we'll only mention the command log part
 		LcOpenExtrasMenu:                    "명령어 로그 메뉴 열기",
 		LcShowingGitDiff:                    "showing output for:",
@@ -536,7 +538,7 @@ func koreanTranslationSet() TranslationSet {
 			UnstageFile:                       "Unstage file",
 			UnstageAllFiles:                   "Unstage all files",
 			StageAllFiles:                     "Stage all files",
-			IgnoreExcludeFile:                 "Ignore file",
+			LcIgnoreExcludeFile:               "ignore file",
 			Commit:                            "커밋",
 			EditFile:                          "파일 수정",
 			Push:                              "푸시",
@@ -561,6 +563,7 @@ func koreanTranslationSet() TranslationSet {
 			UpdateRemote:                      "Update remote",
 			ApplyPatch:                        "Apply patch",
 			Stash:                             "Stash",
+			RenameStash:                       "Rename stash",
 			RemoveSubmodule:                   "서브모듈 삭제",
 			ResetSubmodule:                    "서브모듈 Reset",
 			AddSubmodule:                      "서브모듈 추가",
