@@ -83,6 +83,8 @@ func polishTranslationSet() TranslationSet {
 		SureDropStashEntry:                  "Jesteś pewny, że chcesz porzucić tę pozycję w schowku?",
 		NoTrackedStagedFilesStash:           "Nie masz śledzonych/zatwierdzonych plików do przechowania",
 		StashChanges:                        "Przechowaj zmiany",
+		LcRenameStash:                       "rename stash",
+		RenameStashPrompt:                   "Rename stash: {{.stashName}}",
 		OpenConfig:                          "otwórz konfigurację",
 		EditConfig:                          "edytuj konfigurację",
 		ForcePush:                           "Wymuś wysłanie",
@@ -212,7 +214,7 @@ func polishTranslationSet() TranslationSet {
 		LcStashOptions:                      "Opcje schowka",
 		NotARepository:                      "Błąd: nie jesteś w repozytorium",
 		LcJump:                              "przeskocz do panelu",
-		ExitLineByLineMode:                  `wyście z trybu "linia po linii"`,
+		ExitCustomPatchBuilder:              `wyście z trybu "linia po linii"`,
 		EnterUpstream:                       `Podaj gałąź nadrzędną jako '<remote> <branchname>'`,
 		ReturnToRemotesList:                 `wróć do listy repozytoriów zdalnych`,
 		IgnoreTracked:                       "Ignoruj plik śledzony",
