@@ -26,5 +26,5 @@ cd ..
 git clone --bare ./repo other_repo
 cd repo
 
-git submodule add ../other_repo
+git -c protocol.file.allow=always submodule add ../other_repo
 git commit -am "add submodule"
